@@ -1,33 +1,12 @@
 var panel = new Panel
 var panelScreen = panel.screen
-var freeEdges = {"bottom": true, "top": true, "left": true, "right": true}
 
-for (i = 0; i < panelIds.length; ++i) {
-    var tmpPanel = panelById(panelIds[i])
-    if (tmpPanel.screen == panelScreen) {
-        // Ignore the new panel
-        if (tmpPanel.id != panel.id) {
-            freeEdges[tmpPanel.location] = false;
-        }
-    }
-}
+// No need to set panel.location as ShellCorona::addPanel will automatically pick one available edge
 
-if (freeEdges["bottom"] == true) {
-    panel.location = "bottom";
-} else if (freeEdges["top"] == true) {
-    panel.location = "top";
-} else if (freeEdges["left"] == true) {
-    panel.location = "left";
-} else if (freeEdges["right"] == true) {
-    panel.location = "right";
-} else {
-    // There is no free edge, so leave the default value
-    panel.location = "top";
-}
 // For an Icons-Only Task Manager on the bottom, *3 is too much, *2 is too little
 // Round down to next highest even number since the Panel size widget only displays
 // even numbers
-panel.height = 2 * Math.floor(gridUnit * 2.5 / 2)
+panel.height = 44 // 2 * Math.floor(gridUnit * 2.5 / 2)
 
 // Restrict horizontal panel to a maximum size of a 21:9 monitor
 const maximumAspectRatio = 21/9;
@@ -42,10 +21,7 @@ if (panel.formFactor === "horizontal") {
     }
 }
 
-var kickoff = panel.addWidget("org.kde.plasma.kickoff")
-kickoff.currentConfigGroup = ["Shortcuts"]
-kickoff.writeConfig("global", "Alt+F1")
-
+panel.addWidget("org.kde.plasma.kickoff")
 //panel.addWidget("org.kde.plasma.showActivityManager")
 panel.addWidget("org.kde.plasma.pager")
 panel.addWidget("org.kde.plasma.icontasks")
